@@ -4,21 +4,25 @@
 #' growing library. If called without any parameters, a random quote is
 #' returned.
 #'
-#' @param ID \code{\link{character}}, qoute ID to be returned.
-#' @param author \code{\link{character}}, all quotes by specified author.
-#' @param separated \code{\link{logical}}, return result in separated form.
+#' @param ID [character] (*optional*): qoute ID to be returned.
+#'
+#' @param separated [logical] (*with default*): return result in separated form.
+#'
 #' @return Returns a character with quote and respective (false) author.
-#' @section Function version: 0.1.1
-#' @author Michael Dietze, GFZ Potsdam (Germany)
+#'
+#' @section Function version: 0.1.4
+#'
+#' @author Michael Dietze, GFZ Potsdam (Germany), Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS - Université Bordeaux Montaigne (France)
+#'
 #' @examples
 #'
 #' ## ask for an arbitrary qoute
 #' get_Quote()
 #'
+#' @md
 #' @export
 get_Quote <- function(
   ID,
-  author,
   separated = FALSE
 ) {
 
@@ -39,9 +43,9 @@ get_Quote <- function(
     c("An arctic sediment outcrop", "Marmor, Stein und Eisen bricht..."),
     c("A common luminescence reader customer", "If anything can go wrong, it will."),
     c("A blue LED to a trapped electron", "Resistance is futile."),
-    c("A trapped electron to a yellow LED", "Well, that's all?"),
+    c("A trapped electron to a yellow LED", "Well, that's all you've got?"),
     c("A weathering rock", "Who wants to live forever?"),
-    c("A new pIRIR derivative", "20000 miles below the sea."),
+    c("A new pIRIR derivative", "20,000 miles below the sea."),
     c("Robert Oppenheimer", "I want this thing to work by just pressing one button."),
     c("An arbitrary member of the CRAN team", "No shirt, no shoes, no service!"),
     c("Rubber mallet to steel cylinder", "Let's rock and roll."),
@@ -58,25 +62,30 @@ get_Quote <- function(
     c("A motivated R-Team member", "We are doing this not just for statistical reasons, there is real science behind it!"),
     c("An enthusiastic cabaret artist", "Political elections are like brushing teeth: if you don't do it, things become brown."),
     c("An unbiased reviewer", "The data is too poor to be published in QG, try a higher ranked journal."),
-    c("R Team member, asked about statistical details", "No idea, I'm just here for visualisation."),
+    c("R Team member, asked about statistical details", "No idea, I'm just here for the visualisation."),
     c("An arbitrary unexperienced RLum-user", "Little by little, the bird builds its nest."),
-    c("The answer to life, the universe and everything", "get_rightAnswer()")
-
+    c("The answer to life, the universe and everything", "get_rightAnswer()"),
+    c("Der Tatortreiniger", "Dreck ist nur Materie am falschen Ort."),
+    c("Die Ex vom Tatortreiniger", "Das Ziel ist im Weg."),
+    c("Bright grain to dim grains", "I'm so shiny!"),
+    c("Fast component to slow component", "Life is short!"),
+    c("Fast component to slow component", "What are you waiting for?"),
+    c("Violet photon to deep trap electron", "Today I'm kicking you out of your comfort zone!"),
+    c("Deep trap electron to infrared photon", "Don't bother me, I need to rest."),
+    c("A single grain", "I feel so lonley."),
+    c("Luminescence data to Bayesian process", "Don't you ever touch me again."),
+    c("Quartz grain to heating plate", "Go ahead, I need a phase change.")
     )
 
   ## Check input data
-  if(missing(ID) == TRUE & missing(author) == TRUE) {
+  if(missing(ID) == TRUE) {
     ID <- sample(x = seq(from = 1,
                          to = nrow(quotes)),
                  size = 1)
-  } else if(missing(ID) == TRUE) {
-    ID <- seq(from = 1,
-              to = nrow(quotes))[quotes[,1] == author]
   }
 
   ## check for correct ID and generate qoute
   if(length(ID) < 1 | ID > nrow(quotes)) {
-
     quote.out <- "Sorry, but this was an impossible task!"
 
   } else {
