@@ -3,156 +3,146 @@
 #' The function provides a standardised plot output for spectrum data of an
 #' RLum.Data.Spectrum S4 class object
 #'
-#' \bold{Matrix structure} \cr (cf. \code{\linkS4class{RLum.Data.Spectrum}})
+#' **Matrix structure** \cr (cf. [RLum.Data.Spectrum-class])
 #'
-#' \itemize{ \item \code{rows} (x-values): wavelengths/channels (xlim, xlab)
-#' \item \code{columns} (y-values): time/temperature (ylim, ylab) \item
-#' \code{cells} (z-values): count values (zlim, zlab) }
+#' - `rows` (x-values): wavelengths/channels (xlim, xlab)
+#' - `columns` (y-values): time/temperature (ylim, ylab)
+#' - `cells` (z-values): count values (zlim, zlab)
 #'
-#' \emph{Note: This nomenclature is valid for all plot types of this
-#' function!}\cr
+#' *Note: This nomenclature is valid for all plot types of this function!*
 #'
-#' \bold{Nomenclature for value limiting}
+#' **Nomenclature for value limiting**
 #'
-#' \code{xlim}: Limits values along the wavelength axis\cr \code{ylim}: Limits
-#' values along the time/temperature axis\cr \code{zlim}: Limits values along
-#' the count value axis\cr
+#' - `xlim`: Limits values along the wavelength axis
+#' - `ylim`: Limits values along the time/temperature axis
+#' - `zlim`: Limits values along the count value axis
 #'
-#' \bold{Energy axis re-calculation}
-#'
-#' If the argument \code{xaxis.energy = TRUE} is chosen, instead intensity vs.
-#' wavelength the spectrum is plotted as intensiyt vs. energy. Therefore the
-#' entire spectrum is re-recaluated (e.g., Appendix 4 in Blasse and Grabmeier,
-#' 1994):
-#'
-#' The intensity of the spectrum (z-values) is re-calcualted using the
-#' following equation:
-#'
-#' \deqn{\phi_{E} = \phi_{\lambda} * \lambda^2 / (hc)}
-#'
-#' with \eqn{\phi_{E}} the intensity per interval of energy \eqn{E} (eV),
-#' \eqn{\phi_{\lambda}} the intensity per interval of wavelength \eqn{\lambda}
-#' (nm) and \eqn{h} (eV/s) the Planck constant and \eqn{c} (m/s) the velocity
-#' of light.
-#'
-#' For transforming the wavelength axis (x-values) the equation
-#'
-#' \deqn{E = hc/\lambda}
-#'
-#' is used. For further details please see the cited the literature.\cr
-#'
-#' \bold{Details on the plot functions}
+#' **Details on the plot functions**
 #'
 #' Spectrum is visualised as 3D or 2D plot. Both plot types are based on
-#' internal R plot functions. \cr
+#' internal R plot functions.
 #'
-#' \bold{\code{plot.type = "persp"}}
+#'**`plot.type = "persp"`**
 #'
-#' Arguments that will be passed to \code{\link{persp}}: \itemize{ \item
-#' \code{shade}: default is \code{0.4} \item \code{phi}: default is \code{15}
-#' \item \code{theta}: default is \code{-30} \item \code{expand}: default is
-#' \code{1} \item \code{ticktype}: default is \code{detailed}, \code{r}: default is \code{10}}
+#' Arguments that will be passed to [persp]:
 #'
-#' \emph{Note: Further parameters can be adjusted via \code{par}. For example
+#' - `shade`: default is `0.4`
+#' - `phi`: default is `15`
+#' - `theta`: default is `-30`
+#' - `expand`: default is `1`
+#' - `ticktype`: default is `detailed`, `r`: default is `10`
+#'
+#' **Note:** Further parameters can be adjusted via `par`. For example
 #' to set the background transparent and reduce the thickness of the lines use:
-#' \code{par(bg = NA, lwd = 0.7)} previous the function call.}
+#' `par(bg = NA, lwd = 0.7)` previous the function call.
 #'
-#' \bold{\code{plot.type = "single"}}\cr
+#'**`plot.type = "single"`**
 #'
 #' Per frame a single curve is returned. Frames are time or temperature
-#' steps.\cr
+#' steps.
 #'
-#' \bold{\code{plot.type = "multiple.lines"}}\cr
+#'**`plot.type = "multiple.lines"`**
 #'
-#' All frames plotted in one frame.\cr
+#' All frames plotted in one frame.
 #'
-#' \bold{\code{plot.type = "transect"}}\cr
+#'**`plot.type = "transect"`**
 #'
 #' Depending on the selected wavelength/channel range a transect over the
 #' time/temperature (y-axis) will be plotted along the wavelength/channels
 #' (x-axis). If the range contains more than one channel, values (z-values) are
-#' summed up. To select a transect use the \code{xlim} argument, e.g.
-#' \code{xlim = c(300,310)} plot along the summed up count values of channel
-#' 300 to 310.\cr
+#' summed up. To select a transect use the `xlim` argument, e.g.
+#' `xlim = c(300,310)` plot along the summed up count values of channel
+#' 300 to 310.
 #'
-#' \bold{Further arguments that will be passed (depending on the plot type)}
+#' **Further arguments that will be passed (depending on the plot type)**
 #'
-#' \code{xlab}, \code{ylab}, \code{zlab}, \code{xlim}, \code{ylim},
-#' \code{zlim}, \code{main}, \code{mtext}, \code{pch}, \code{type} ("single", "multiple.lines",
-#' "interactive"), \code{col},
-#' \code{border}, \code{box} \code{lwd}, \code{bty}, \code{showscale} ("interactive") \cr
+#' `xlab`, `ylab`, `zlab`, `xlim`, `ylim`,
+#' `zlim`, `main`, `mtext`, `pch`, `type` ("single", "multiple.lines", "interactive"),
+#' `col`, `border`, `box` `lwd`, `bty`, `showscale` ("interactive")
 #'
-#' @param object \code{\linkS4class{RLum.Data.Spectrum}} or \code{\link{matrix}} (\bold{required}): S4
-#' object of class \code{RLum.Data.Spectrum} or a \code{matrix} containing count values of the spectrum.\cr
-#' Please note that in case of a matrix rownames and colnames are set automatically if not provided.
+#' @param object [RLum.Data.Spectrum-class] or [matrix] (**required**):
+#' S4 object of class `RLum.Data.Spectrum` or a `matrix` containing count
+#' values of the spectrum.\cr
+#' Please note that in case of a matrix rownames and colnames are set
+#' automatically if not provided.
 #'
-#' @param par.local \code{\link{logical}} (with default): use local graphical
-#' parameters for plotting, e.g. the plot is shown in one column and one row.
-#' If \code{par.local = FALSE} global parameters are inherited.
-#' @param plot.type \code{\link{character}} (with default): plot type, for
-#' 3D-plot use \code{persp}, or \code{interactive}, for a 2D-plot \code{contour},
-#' \code{single} or \code{multiple.lines} (along the time or temperature axis)
-#' or \code{transect} (along the wavelength axis) \cr
+#' @param par.local [logical] (*with default*):
+#' use local graphical parameters for plotting, e.g. the plot is shown in one column and one row.
+#' If `par.local = FALSE` global parameters are inherited.
+#' @param plot.type [character] (*with default*): plot type, for
+#' 3D-plot use `persp`, or `interactive`, for a 2D-plot `contour`,
+#' `single` or `multiple.lines` (along the time or temperature axis)
+#' or `transect` (along the wavelength axis) \cr
 #'
-#' @param optical.wavelength.colours \code{\link{logical}} (with default): use
-#' optical wavelength colour palette. Note: For this, the spectrum range is
-#' limited: \code{c(350,750)}. Own colours can be set with the argument
-#' \code{col}.
+#' @param optical.wavelength.colours [logical] (*with default*):
+#' use optical wavelength colour palette. Note: For this, the spectrum range is
+#' limited: `c(350,750)`. Own colours can be set with the argument `col`. If you provide already
+#' binned spectra, the colour assignment is likely to be wrong, since the colour gradients are calculated
+#' using the bin number.
 #'
-#' @param bg.channels \code{\link{vector}} (optional): defines channel for
-#' background subtraction If a vector is provided the mean of the channels is
-#' used for subtraction. Note: Background subtraction is applied prior to
-#' channel binning
+#' @param bg.spectrum [RLum.Data.Spectrum-class] or [matrix] (*optional*): Spectrum
+#' used for the background subtraction. By definition, the background spectrum should have been
+#' measured with the same setting as the signal spectrum. If a spectrum is provided, the
+#' argument `bg.channels` works only on the provided background spectrum.
 #'
-#' @param bin.rows \code{\link{integer}} (with defaul): allow summing-up
-#' wavelength channels (horizontal binning), e.g. \code{bin.rows = 2} two
-#' channels are summed up
+#' @param bg.channels [vector] (*optional*):
+#' defines channel for background subtraction If a vector is provided the mean
+#' of the channels is used for subtraction. If a spectrum is provided via `bg.spectrum`, this
+#' argument only works on the `bg.spectrum`.
 #'
-#' @param bin.cols \code{\link{integer}} (with default): allow summing-up
-#' channel counts (vertical binning) for plotting, e.g. \code{bin.cols = 2} two
-#' channels are summed up
+#' **Note:** Background subtraction is applied prior to channel binning
 #'
-#' @param rug \code{\link{logical}} (with default): enables or disables colour
-#' rug. Currently only implemented for plot type \code{multiple.lines} and
-#' \code{single}
+#' @param bin.rows [integer] (*with default*):
+#' allow summing-up wavelength channels (horizontal binning),
+#' e.g. `bin.rows = 2` two channels are summed up.
+#' Binning is applied after the background subtraction.
 #'
-#' @param limit_counts \code{\link{numeric}} (optional): value to limit all count values to
-#' this value, i.e. all count values above this threshold will be replaced by this threshold. This
-#' is helpfull especially in case of TL-spectra.
+#' @param bin.cols [integer] (*with default*):
+#' allow summing-up channel counts (vertical binning) for plotting,
+#' e.g. `bin.cols = 2` two channels are summed up.
+#' Binning is applied after the background subtraction.
 #'
-#' @param xaxis.energy \code{\link{logical}} (with default): enables or
-#' disables energy instead of wavelength axis. Note: This option means not only
-#' simnply redrawing the axis, insteadly the spectrum in terms of intensity is
-#' recalculated, s. details.
+#' @param norm [character] (*optional*): Normalise data to the maximum (`norm = "max"`) or
+#' minimum (`norm = "min"`) count values. The normalisation is applied after the binning.
 #'
-#' @param legend.text \code{\link{character}} (with default): possiblity to
-#' provide own legend text. This argument is only considered for plot types
-#' providing a legend, e.g. \code{plot.type="transect"}
+#' @param rug [logical] (*with default*):
+#' enables or disables colour rug. Currently only implemented for plot
+#' type `multiple.lines` and `single`
 #'
-#' @param \dots further arguments and graphical parameters that will be passed
-#' to the \code{plot} function.
+#' @param limit_counts [numeric] (*optional*):
+#' value to limit all count values to this value, i.e. all count values above
+#' this threshold will be replaced by this threshold. This is helpful
+#' especially in case of TL-spectra.
+#'
+#' @param xaxis.energy [logical] (*with default*): enables or disables energy instead of
+#' wavelength axis. For the conversion the function [convert_Wavelength2Energy] is used.
+#'
+#' **Note:** This option means not only simnply redrawing the axis,
+#' instead the spectrum in terms of intensity is recalculated, s. details.
+#'
+#' @param legend.text [character] (*with default*):
+#' possiblity to provide own legend text. This argument is only considered for
+#' plot types providing a legend, e.g. `plot.type="transect"`
+#'
+#' @param ... further arguments and graphical parameters that will be passed
+#' to the `plot` function.
 #'
 #' @return Returns a plot.
 #'
-#' @note Not all additional arguments (\code{...}) will be passed similarly!
+#' @note Not all additional arguments (`...`) will be passed similarly!
 #'
-#' @section Function version: 0.5.3
+#' @section Function version: 0.6.2
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
-#' (France)
+#' @author
+#' Sebastian Kreutzer, IRAMAT-CRP2A, UMR 5060, CNRS - Université Bordeaux Montaigne (France)
 #'
-#' @seealso \code{\linkS4class{RLum.Data.Spectrum}}, \code{\link{plot}},
-#' \code{\link{plot_RLum}}, \code{\link{persp}}, \code{\link[plotly]{plot_ly}},
-#' \code{\link{contour}}
-#'
-#' @references Blasse, G., Grabmaier, B.C., 1994. Luminescent Materials.
-#' Springer.
+#' @seealso [RLum.Data.Spectrum-class], [convert_Wavelength2Energy], [plot], [plot_RLum], [persp],
+#' [plotly::plot_ly], [contour]
 #'
 #' @keywords aplot
 #'
 #' @examples
 #'
-#'
 #' ##load example data
 #' data(ExampleData.XSYG, envir = environment())
 #'
@@ -165,20 +155,32 @@
 #'                         bin.cols = 1)
 #'
 #' ##(2) plot spectrum (3D)
-#' plot_RLum.Data.Spectrum(TL.Spectrum,
-#'                         plot.type="persp",
-#'                         xlim = c(310,750),
-#'                         ylim = c(0,100),
-#'                         bin.rows=10,
-#'                         bin.cols = 1)
+#' plot_RLum.Data.Spectrum(
+#'   TL.Spectrum,
+#'   plot.type="persp",
+#'   xlim = c(310,750),
+#'   ylim = c(0,100),
+#'   bin.rows=10,
+#'   bin.cols = 1)
 #'
-#' ##(3) plot multiple lines (2D) - multiple.lines (with ylim)
-#' plot_RLum.Data.Spectrum(TL.Spectrum,
-#'                         plot.type="multiple.lines",
-#'                         xlim = c(310,750),
-#'                         ylim = c(0,100),
-#'                         bin.rows=10,
-#'                         bin.cols = 1)
+#'##(3) plot spectrum on energy axis
+#'##please note the background subtraction
+#'plot_RLum.Data.Spectrum(TL.Spectrum,
+#' plot.type="persp",
+#' ylim = c(0,200),
+#' bin.rows=10,
+#' bg.channels = 10,
+#' bin.cols = 1,
+#' xaxis.energy = TRUE)
+#'
+#' ##(4) plot multiple lines (2D) - multiple.lines (with ylim)
+#' plot_RLum.Data.Spectrum(
+#'  TL.Spectrum,
+#'  plot.type="multiple.lines",
+#'  xlim = c(310,750),
+#'  ylim = c(0,100),
+#'  bin.rows=10,
+#'  bin.cols = 1)
 #'
 #' \dontrun{
 #'  ##(4) interactive plot using the package plotly ("surface")
@@ -206,15 +208,18 @@
 #'
 #' }
 #'
+#' @md
 #' @export
 plot_RLum.Data.Spectrum <- function(
   object,
   par.local = TRUE,
   plot.type = "contour",
   optical.wavelength.colours = TRUE,
-  bg.channels,
+  bg.spectrum = NULL,
+  bg.channels = NULL,
   bin.rows = 1,
   bin.cols = 1,
+  norm = NULL,
   rug = TRUE,
   limit_counts = NULL,
   xaxis.energy = FALSE,
@@ -248,7 +253,8 @@ plot_RLum.Data.Spectrum <- function(
 
 
     }else{
-      stop("[plot_RLum.Data.Spectrum()] Input object neither of class 'RLum.Data.Spectrum' nor 'matrix'")
+      stop("[plot_RLum.Data.Spectrum()] Input object neither of class 'RLum.Data.Spectrum' nor 'matrix'.",
+           call. = FALSE)
 
     }
 
@@ -274,24 +280,17 @@ plot_RLum.Data.Spectrum <- function(
   }
 
   # Do energy axis conversion -------------------------------------------------------------------
-  if (xaxis.energy) {
-    temp.object.data <- sapply(1:ncol(object@data), function(x) {
-      object@data[,x] * x ^ 2 / (4.13566733e-015 * 299792458e+09)
-    })
+  if (xaxis.energy){
+    ##conversion
+    object <- convert_Wavelength2Energy(object, digits = 5)
 
-    ##preserve column and rownames
-    colnames(temp.object.data) <- colnames(object@data)
-    rownames(temp.object.data) <-
-      4.13566733e-015 * 299792458e+09 / as.numeric(rownames(object@data))
-
-    ##write back to original data
-    object@data <-
-      temp.object.data[order(as.numeric(rownames(temp.object.data))),]
+    ##modify row order (otherwise subsequent functions, like persp, have a problem)
+    object@data[] <- object@data[order(as.numeric(rownames(object@data))),]
+    rownames(object@data) <- sort(as.numeric(rownames(object@data)))
 
   }
 
 
-
   ##deal with addition arguments
   extraArgs <- list(...)
 
@@ -381,7 +380,8 @@ plot_RLum.Data.Spectrum <- function(
 
 
   # prepare values for plot ---------------------------------------------------
-  temp.xyz <- get_RLum(object)
+  ##copy data
+  temp.xyz <- object@data
 
   ##check for NULL column names
   if(is.null(colnames(temp.xyz))){
@@ -413,118 +413,137 @@ plot_RLum.Data.Spectrum <- function(
   ## time/temp
   y <- as.numeric(colnames(temp.xyz))
 
+  # Background spectrum -------------------------------------------------------------------------
+  if(!is.null(bg.spectrum)){
+    if(class(bg.spectrum) == "RLum.Data.Spectrum" || class(bg.spectrum) == "matrix"){
+      ##case RLum
+      if(class(bg.spectrum) == "RLum.Data.Spectrum") bg.xyz <- bg.spectrum@data
 
-  # Background subtraction ---------------------------------------------------
+      ##case matrix
+      if(class(bg.spectrum) == "matrix") bg.xyz <- bg.spectrum
 
-  if(missing(bg.channels) == FALSE){
+      ##take care of channel settings, otherwise set bg.channels
+      if(is.null(bg.channels))
+        bg.channels <- c(1:ncol(bg.xyz))
 
-    if(length(bg.channels) > 1){
+      ##set rownames
+      if(is.null(rownames(bg.xyz)))
+        rownames(bg.xyz) <- 1:nrow(bg.xyz)
 
-      temp.bg.signal <- rowMeans(temp.xyz[,bg.channels])
-      temp.xyz <- temp.xyz[,1:ncol(temp.xyz)] - temp.bg.signal
+      ##convert to energy scale if needed
+      if(xaxis.energy){
+
+        #conversion
+        bg.xyz <- convert_Wavelength2Energy(cbind(as.numeric(rownames(bg.xyz)), bg.xyz), digits = 5)
+        rownames(bg.xyz) <- bg.xyz[,1]
+        bg.xyz <- bg.xyz[,-1, drop = FALSE]
+
+        ##modify row order (otherwise subsequent functions, like persp, have a problem)
+        bg.xyz <- bg.xyz[order(as.numeric(rownames(bg.xyz))),,drop = FALSE]
+        rownames(bg.xyz) <- sort(as.numeric(rownames(bg.xyz)))
+
+      }
+
+      ##reduce for xlim
+      bg.xyz <- bg.xyz[as.numeric(rownames(bg.xyz)) >= xlim[1] &
+                             as.numeric(rownames(bg.xyz)) <= xlim[2],,drop = FALSE]
 
     }else{
+      stop("[plot_RLum.Data.Spectrum()] Input for 'bg.spectrum' not supported, please check manual!", call. = FALSE)
 
-      temp.xyz <- temp.xyz[,1:ncol(temp.xyz)] - temp.xyz[,bg.channels]
-      temp.xyz <- ifelse(temp.xyz < 0, mean(temp.xyz[,bg.channels]), temp.xyz)
+    }
+
+  }
+
+  # Background subtraction ---------------------------------------------------
+  if(!is.null(bg.channels)){
+    ##set background object if not available
+    if(is.null(bg.spectrum)) bg.xyz <- temp.xyz
+
+    if(max(bg.channels) > ncol(bg.xyz) || bg.channels <= 0){
+      ##correct the mess
+      bg.channels <- sort(unique(bg.channels))
+      bg.channels[bg.channels <= 0] <- 1
+      bg.channels[bg.channels >= ncol(bg.xyz)] <- ncol(bg.xyz)
+
+      warning(
+        paste0(
+          "[plot_RLum.Data.Spectrum()] 'bg.channels' out of range, corrected to: ",
+          min(bg.channels),
+          ":",
+          max(bg.channels)
+        ), call. = FALSE)
+    }
+
+    if(length(bg.channels) > 1){
+      temp.bg.signal <- rowMeans(bg.xyz[,bg.channels])
+      temp.xyz <- temp.xyz - temp.bg.signal
+
+    }else{
+      temp.xyz <- temp.xyz - bg.xyz[,bg.channels]
 
     }
 
     ##set values < 0 to 0
-    temp.xyz <- ifelse(temp.xyz < 0, mean(temp.xyz[,bg.channels[1]]), temp.xyz)
+    temp.xyz[temp.xyz < 0] <- 0
+
+    ##check worst case
+    if(sum(temp.xyz) == 0){
+      message("[plot_RLum.Data.Spectrum()] After background subtraction all counts < 0. Nothing plotted, NULL returned!")
+      return(NULL)
+    }
 
   }
 
 
   # Channel binning ---------------------------------------------------------
+  ##rewrite arguments; makes things easier
+  bin.cols <- bin.cols[1]
+  bin.rows <- bin.rows[1]
 
-  ##fatal checks
-  if(bin.cols < 1 | bin.rows < 1){
+  ##fatal check (not needed anymore, but never change running code)
+  if(bin.cols < 1 | bin.rows < 1)
     stop("[plot_RLum.Data.Spectrum()] 'bin.cols' and 'bin.rows' have to be > 1!", call. = FALSE)
 
-  }
-
   if(bin.rows > 1){
+    temp.xyz <- .matrix_binning(temp.xyz, bin_size = bin.rows, bin_col = FALSE, names = "mean")
+    x <- as.numeric(rownames(temp.xyz))
 
-    ##calculate n.rows
-    n.rows <- nrow(temp.xyz)
+    ##remove last channel (this is the channel that included less data)
+    if(length(x)%%bin.rows != 0){
+      ##return warning
+      warning(
+        paste0("[plot_RLum.Data.Spectrum()] ",length(x)%%bin.rows,
+               " channel(s) removed due to row (wavelength) binning."),
+        call. = FALSE)
 
-    ##modulo operation for the number of groups
-    bin.group.rest <- n.rows%%bin.rows
-
-    ##define groups for binning
-    bin.group <- rep(1:(n.rows/bin.rows), 1, each = bin.rows)
-
-    ##add last group
-    bin.group <- c(bin.group, rep(n.rows/bin.rows + 1, 1, each = bin.group.rest))
-
-    ##sum up rows
-    temp.xyz <- rowsum(temp.xyz, bin.group)
-
-    ##correct labelling
-    x <- x[seq(1, n.rows, bin.rows)]
-
-    ## to avoid odd plots remove last group if bin.rows is not a multiple
-    ## of the row number
-    if(bin.group.rest != 0){
-      temp.xyz <- temp.xyz[-nrow(temp.xyz),]
+      ##do it
+      temp.xyz <- temp.xyz[-length(x),]
       x <- x[-length(x)]
 
-      warning("Last wavelength channel has been removed due to binning.")
-
     }
 
-    ##replace rownames
-    rownames(temp.xyz) <- as.character(x)
-
-    rm(bin.group.rest)
-
   }
 
-
   if(bin.cols > 1){
+    temp.xyz <- .matrix_binning(temp.xyz, bin_size = bin.cols, bin_col = TRUE, names = "groups")
+    y <- as.numeric(colnames(temp.xyz))
 
-    ##calculate n.cols
-    n.cols <- ncol(temp.xyz)
+    ##remove last channel (this is the channel that included less data)
+    if(length(y)%%bin.cols != 0){
 
-    ##check for validity
-    if(bin.cols > n.cols){
+      ##return warning
+      warning(
+        paste0("[plot_RLum.Data.Spectrum()] ",length(y)%%bin.cols,
+               " channel(s) removed due to column (frame) binning."),
+        call. = FALSE)
 
-      bin.cols <- n.cols
-      warning("bin.cols > the number of columns. Value reduced to number of cols.")
-
-    }
-
-    ##modulo operation for the number of groups
-    bin.group.rest <- n.cols%%bin.cols
-
-    ##define groups for binning
-    bin.group <- rep(1:(n.cols/bin.cols), 1, each = bin.cols)
-
-    ##add last group
-    bin.group <- c(bin.group, rep(n.cols/bin.cols + 1, 1, each = bin.group.rest))
-
-    ##sum up cols
-    temp.xyz <- rowsum(t(temp.xyz), bin.group)
-    temp.xyz <- t(temp.xyz)
-
-    ##correct labeling
-    y <- y[seq(1, n.cols, bin.cols)]
-
-    ## to avoid odd plots remove last group if bin.cols is not a multiple
-    ## of the col number
-    if(bin.group.rest != 0){
-
-      temp.xyz <- temp.xyz[,-ncol(temp.xyz)]
+      ##do it
+      temp.xyz <- temp.xyz[,-length(y)]
       y <- y[-length(y)]
 
-      warning("Last count channel has been removed due to column binning.")
-
     }
 
-    ##replace colnames
-    colnames(temp.xyz) <- as.character(y)
-
   }
 
   ##limit z-values if requested, this idea was taken from the Diss. by Thomas Schilles, 2002
@@ -533,18 +552,29 @@ plot_RLum.Data.Spectrum <- function(
 
   }
 
+
+  # Normalise if wanted -------------------------------------------------------------------------
+  if(!is.null(norm)){
+    if(norm == "min")
+      temp.xyz <- temp.xyz/min(temp.xyz)
+
+    if(norm == "max")
+      temp.xyz <- temp.xyz/max(temp.xyz)
+
+  }
+
+
   ##check for zlim
   zlim <- if("zlim" %in% names(extraArgs)) {extraArgs$zlim} else
   {range(temp.xyz)}
 
 
   # set color values --------------------------------------------------------
-
   if("col" %in% names(extraArgs) == FALSE | plot.type == "single" | plot.type == "multiple.lines"){
 
     if(optical.wavelength.colours == TRUE | (rug == TRUE & (plot.type != "persp" & plot.type != "interactive"))){
 
-      ##make different colour palette for energy valuesw
+      ##make different colour palette for energy values
       if (xaxis.energy) {
         col.violet <- c(2.76, ifelse(max(xlim) <= 4.13, max(xlim), 4.13))
         col.blue <- c(2.52, 2.76)
@@ -571,6 +601,7 @@ plot_RLum.Data.Spectrum <- function(
 
 
       }else{
+        ##wavelength colours for wavelength axis
         col.violet <- c(ifelse(min(xlim) <= 300, min(xlim), 300),450)
         col.blue <- c(450,495)
         col.green <- c(495,570)
@@ -580,7 +611,6 @@ plot_RLum.Data.Spectrum <- function(
         col.infrared <-
           c(790, ifelse(max(xlim) >= 800, max(xlim), 800))
 
-
         #set colour palette
         col <- unlist(sapply(1:length(x), function(i){
 
@@ -597,14 +627,11 @@ plot_RLum.Data.Spectrum <- function(
 
       }
 
-
-
       ##find unique colours
       col.unique <- unique(col)
 
       ##if only one colour value, then skip gradient calculation as it causes
-      ## an error
-
+      ##an error
       if(length(col.unique) > 1){
 
         ##set colour function for replacement
@@ -612,25 +639,21 @@ plot_RLum.Data.Spectrum <- function(
 
         ##get index for colour values to be cut from the current palette
         col.unique.index <-
-          sapply(1:length(col.unique), function(i) {
-            max(which(col == col.unique[i]))
-
-          })
+          vapply(col.unique, function(i) {
+            max(which(col == i))
 
+          }, numeric(1))
 
         ##remove last index (no colour gradient needed), for energy axis use the first value
         col.unique.index <- col.unique.index[-length(col.unique.index)]
 
-
         ##set borders for colour gradient recalculation
-        col.unique.index.min <- col.unique.index - (50)/bin.rows
-        col.unique.index.max <- col.unique.index + (50)/bin.rows
+        col.unique.index.min <- col.unique.index - (50/bin.rows)
+        col.unique.index.max <- col.unique.index + (50/bin.rows)
 
         ##set negative values to the lowest index
         col.unique.index.min[col.unique.index.min<=0] <- 1
 
-
-
         ##build up new index sequence (might be better)
         col.gradient.index <- as.vector(unlist((
           sapply(1:length(col.unique.index.min), function(j){
@@ -689,15 +712,15 @@ plot_RLum.Data.Spectrum <- function(
   if(par.local == TRUE){par(mfrow=c(1,1), cex = cex)}
 
   ##rest plot type for 1 column matrix
-  if(ncol(temp.xyz) == 1){
-    plot.type = "single"
-    warning("[plot_RLum.Data.Spectrum()] Single column matrix: plot.type has been automatically reset to 'single'")
+  if(ncol(temp.xyz) == 1 && plot.type != "single"){
+    plot.type <- "single"
+    warning("[plot_RLum.Data.Spectrum()] Single column matrix: plot.type has been automatically reset to 'single'", call. = FALSE)
   }
 
   ##do not let old code break down ...
   if(plot.type == "persp3d"){
     plot.type <- "interactive"
-    warning("[plot_RLum.Data.Spectrum()] 'plot.type' has been automatically reset to interactive!")
+    warning("[plot_RLum.Data.Spectrum()] 'plot.type' has been automatically reset to interactive!", call. = FALSE)
 
   }
 
@@ -705,7 +728,6 @@ plot_RLum.Data.Spectrum <- function(
     ## ==========================================================================#
     ##perspective plot
     ## ==========================================================================#
-
     persp(x, y, temp.xyz,
           shade = shade,
           phi = phi,
@@ -715,7 +737,7 @@ plot_RLum.Data.Spectrum <- function(
           zlab = zlab,
           zlim = zlim,
           scale = TRUE,
-          col = col[1:(length(col)-1)], ##needed due to recycling of the colours
+          col = col[1:(length(x)-1)], ##needed due to recycling of the colours
           main = main,
           expand = expand,
           border = border,
@@ -723,7 +745,6 @@ plot_RLum.Data.Spectrum <- function(
           r = r,
           ticktype = ticktype)
 
-
     ##plot additional mtext
     mtext(mtext, side = 3, cex = cex*0.8)
 
@@ -939,8 +960,7 @@ plot_RLum.Data.Spectrum <- function(
 
 
   }else{
-
-    stop("[plot_RLum.Data.Spectrum()] Unknown plot type.")
+    stop("[plot_RLum.Data.Spectrum()] Unknown plot type.", call. = FALSE)
 
   }
 
